import base64
import os
from pathlib import Path

from authorizenet.constants import constants
from terminusgps.wialon.flags import TokenFlag

BASE_DIR = Path(__file__).resolve().parent.parent

ALLOWED_HOSTS = ["localhost", "127.0.0.1"]
ASGI_APPLICATION = "src.asgi.application"
AWS_PINPOINT_CONFIGURATION_ARN = os.getenv("AWS_PINPOINT_CONFIGURATION_ARN")
AWS_PINPOINT_MAX_PRICE_SMS = os.getenv("AWS_PINPOINT_MAX_PRICE_SMS")
AWS_PINPOINT_MAX_PRICE_VOICE = os.getenv("AWS_PINPOINT_MAX_PRICE_VOICE")
AWS_PINPOINT_POOL_ARN = os.getenv("AWS_PINPOINT_POOL_ARN")
AWS_PINPOINT_PROTECT_ID = os.getenv("AWS_PINPOINT_PROTECT_ID")
TWILIO_ACCOUNT_SID = os.getenv("TWILIO_ACCOUNT_SID")
TWILIO_AUTH_TOKEN = os.getenv("TWILIO_AUTH_TOKEN")
TWILIO_FROM_NUMBER = os.getenv("TWILIO_FROM_NUMBER")
CSRF_COOKIE_SECURE = False
DEBUG = True
DEFAULT_AUTO_FIELD = "django.db.models.BigAutoField"
LANGUAGE_CODE = "en-us"
MERCHANT_AUTH_ENVIRONMENT = constants.SANDBOX
WIALON_TOKEN = os.getenv("WIALON_TOKEN")
MERCHANT_AUTH_LOGIN_ID = os.getenv("MERCHANT_AUTH_LOGIN_ID")
MERCHANT_AUTH_TRANSACTION_KEY = os.getenv("MERCHANT_AUTH_TRANSACTION_KEY")
MERCHANT_AUTH_VALIDATION_MODE = "testMode"
DJANGO_ENCRYPTED_FIELD_ALGORITHM = os.getenv(
    "DJANGO_ENCRYPTED_FIELD_ALGORITHM", "SS20"
)
DJANGO_ENCRYPTED_FIELD_KEY = base64.b64decode(
    os.getenv("DJANGO_ENCRYPTED_FIELD_KEY", "")
)
ROOT_URLCONF = "src.urls"
SECRET_KEY = "k_il7ce@&k-=n9zo+7_^^b4kb+k$7##aa&z#=3(s7jkc_w5j9l"
SESSION_COOKIE_SECURE = False
STATIC_URL = "static/"
TIME_ZONE = "US/Central"
USE_I18N = True
USE_TZ = True
WIALON_TOKEN_ACCESS_TYPE = (
    TokenFlag.VIEW_ACCESS
    | TokenFlag.MANAGE_NONSENSITIVE
    | TokenFlag.MANAGE_SENSITIVE
)
WIALON_RESOURCE_NAME = "Terminus GPS Notifications"
WSGI_APPLICATION = "src.wsgi.application"
NOTIFICATION_DISPATCHERS = {
    "sms": ["terminusgps_notifier.dispatchers.AWSNotificationDispatcher"],
    "voice": [
        "terminusgps_notifier.dispatchers.AWSNotificationDispatcher",
        "terminusgps_notifier.dispatchers.TwilioNotificationDispatcher",
    ],
}

LOGGING = {
    "version": 1,
    "disable_existing_loggers": False,
    "formatters": {
        "simple": {
            "format": "[{asctime} {levelname}] {message}",
            "style": "{",
        },
        "verbose": {
            "format": "[{asctime} {levelname}] {module} {process:d} {thread:d} {message}",
            "style": "{",
        },
    },
    "handlers": {
        "console": {
            "level": "DEBUG",
            "class": "logging.StreamHandler",
            "formatter": "verbose",
        }
    },
    "loggers": {
        "django": {"handlers": ["console"], "propagate": True},
        "django.request": {"handlers": ["console"], "propagate": True},
        "terminusgps_notifier": {
            "handlers": ["console"],
            "level": "DEBUG",
            "propagate": True,
        },
    },
}

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": BASE_DIR / "db.sqlite3",
    }
}

CACHES = {
    "default": {"BACKEND": "django.core.cache.backends.dummy.DummyCache"}
}

INSTALLED_APPS = [
    "django.contrib.admin",
    "django.contrib.admindocs",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.messages",
    "django.contrib.sessions",
    "django.contrib.staticfiles",
    "django.forms",
    "terminusgps_payments.apps.TerminusgpsPaymentsConfig",
    "terminusgps_notifier.apps.TerminusgpsNotifierConfig",
]

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ],
            "autoescape": False,
        },
    }
]

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
]



from django.contrib import admin

from . import models


@admin.register(models.TerminusGPSNotifierCustomer)
class TerminusGPSCustomerAdmin(admin.ModelAdmin):
    list_display = ["user"]


@admin.register(models.MessagePackage)
class MessagePackageAdmin(admin.ModelAdmin):
    list_display = ["customer", "count", "limit"]


@admin.register(models.WialonNotification)
class WialonNotificationAdmin(admin.ModelAdmin):
    list_display = ["resource", "wialon_id"]


@admin.register(models.WialonResource)
class WialonResource(admin.ModelAdmin):
    list_display = ["nm"]


@admin.register(models.WialonUnit)
class WialonUnitAdmin(admin.ModelAdmin):
    list_display = ["nm"]


@admin.register(models.WialonUnitGroup)
class WialonUnitGroupAdmin(admin.ModelAdmin):
    list_display = ["nm"]



import logging

from django.test import TestCase
from django.test.client import Client

logging.disable(logging.ERROR)


class HealthCheckViewTestCase(TestCase):
    def setUp(self) -> None:
        self.client = Client()

    def test_get(self) -> None:
        """Fails if the health check endpoint doesn't return status code 200."""
        response = self.client.get("/v3/health/")
        self.assertEqual(response.status_code, 200)


class DispatchNotificationViewTestCase(TestCase):
    def setUp(self) -> None:
        self.client = Client()

    def test_get_invalid_method(self) -> None:
        """Fails if a request with an invalid method doesn't respond with 404."""
        response = self.client.get("/v3/notify/not_a_method/")
        self.assertEqual(response.status_code, 404)



# Generated by Django 6.0.2 on 2026-02-18 21:52

import django.db.models.deletion
import django.db.models.expressions
import encrypted_field.fields
from decimal import Decimal
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('terminusgps_payments', '0003_alter_subscription_amount_and_more'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='WialonResource',
            fields=[
                ('id', models.PositiveBigIntegerField(primary_key=True, serialize=False)),
                ('nm', models.CharField(blank=True, max_length=50)),
                ('mu', models.IntegerField(blank=True, default=0)),
                ('uacl', models.IntegerField(blank=True, default=0)),
            ],
            options={
                'verbose_name': 'wialon resource',
                'verbose_name_plural': 'wialon resources',
            },
        ),
        migrations.CreateModel(
            name='WialonToken',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', encrypted_field.fields.EncryptedField(max_length=72)),
            ],
            options={
                'verbose_name': 'wialon token',
                'verbose_name_plural': 'wialon tokens',
            },
        ),
        migrations.CreateModel(
            name='WialonUnit',
            fields=[
                ('id', models.PositiveBigIntegerField(primary_key=True, serialize=False)),
                ('nm', models.CharField(blank=True, max_length=50)),
                ('mu', models.IntegerField(blank=True, default=0)),
                ('uacl', models.IntegerField(blank=True, default=0)),
            ],
            options={
                'verbose_name': 'wialon unit',
                'verbose_name_plural': 'wialon units',
            },
        ),
        migrations.CreateModel(
            name='WialonUnitGroup',
            fields=[
                ('id', models.PositiveBigIntegerField(primary_key=True, serialize=False)),
                ('nm', models.CharField(blank=True, max_length=50)),
                ('mu', models.IntegerField(blank=True, default=0)),
                ('uacl', models.IntegerField(blank=True, default=0)),
            ],
            options={
                'verbose_name': 'wialon unit group',
                'verbose_name_plural': 'wialon unit groups',
            },
        ),
        migrations.CreateModel(
            name='TerminusGPSNotifierCustomer',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('messages_count', models.PositiveIntegerField(default=0)),
                ('messages_limit', models.PositiveIntegerField(default=500)),
                ('tax_rate', models.DecimalField(decimal_places=2, default=Decimal('0.0825'), help_text='Enter a tax rate as a decimal.', max_digits=12)),
                ('sub_total', models.DecimalField(decimal_places=2, default=Decimal('60.00'), help_text='Enter a sub total as a decimal.', max_digits=12)),
                ('tax_total', models.GeneratedField(db_persist=True, expression=django.db.models.expressions.CombinedExpression(django.db.models.expressions.CombinedExpression(models.F('sub_total'), '*', django.db.models.expressions.CombinedExpression(models.F('tax_rate'), '+', models.Value(1))), '-', models.F('sub_total')), help_text='Automatically generated tax amount.', output_field=models.DecimalField(decimal_places=2, max_digits=12))),
                ('grand_total', models.GeneratedField(db_persist=True, expression=django.db.models.expressions.CombinedExpression(models.F('sub_total'), '*', django.db.models.expressions.CombinedExpression(models.F('tax_rate'), '+', models.Value(1))), help_text='Automatically generated grand total amount (sub+tax).', output_field=models.DecimalField(decimal_places=2, max_digits=12))),
                ('subscription', models.ForeignKey(blank=True, default=None, help_text='Select an Authorizenet subscription from the list.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='notifier_customer', to='terminusgps_payments.subscription')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='notifier_customer', to=settings.AUTH_USER_MODEL)),
                ('token', models.OneToOneField(blank=True, default=None, help_text='Select a Wialon API token from the list.', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='notifier_customer', to='terminusgps_notifier.wialontoken')),
            ],
            options={
                'verbose_name': 'customer',
                'verbose_name_plural': 'customers',
            },
        ),
        migrations.CreateModel(
            name='MessagePackage',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.DecimalField(decimal_places=2, max_digits=12)),
                ('count', models.IntegerField(default=0)),
                ('limit', models.IntegerField(default=500)),
                ('customer', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='packages', to='terminusgps_notifier.terminusgpsnotifiercustomer')),
            ],
            options={
                'verbose_name': 'message package',
                'verbose_name_plural': 'message packages',
            },
        ),
        migrations.CreateModel(
            name='WialonNotification',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('wialon_id', models.IntegerField(blank=True)),
                ('e', models.IntegerField(blank=True, default=1, verbose_name='enabled')),
                ('n', models.CharField(blank=True, max_length=50)),
                ('txt', models.CharField(blank=True, max_length=1024)),
                ('ta', models.IntegerField(blank=True, default=0)),
                ('td', models.IntegerField(blank=True, default=0)),
                ('ma', models.IntegerField(blank=True, default=0)),
                ('mmtd', models.IntegerField(blank=True, default=0)),
                ('cdt', models.IntegerField(blank=True, default=0)),
                ('mast', models.IntegerField(blank=True, default=0)),
                ('mpst', models.IntegerField(blank=True, default=0)),
                ('cp', models.IntegerField(blank=True, default=0)),
                ('fl', models.IntegerField(choices=[(0, 'First Message'), (1, 'Every Message'), (2, 'Disabled')], default=0)),
                ('tz', models.IntegerField(blank=True, default=0)),
                ('la', models.CharField(blank=True, default='en', max_length=2)),
                ('ac', models.IntegerField(blank=True, default=0)),
                ('un', models.JSONField(blank=True, default=list)),
                ('d', models.CharField(blank=True)),
                ('sch', models.JSONField(blank=True, default=dict)),
                ('ctrl_sch', models.JSONField(blank=True, default=dict)),
                ('trg', models.JSONField(blank=True, default=dict)),
                ('act', models.JSONField(blank=True, default=dict)),
                ('ct', models.IntegerField(blank=True, default=0)),
                ('mt', models.IntegerField(blank=True, default=0)),
                ('resource', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='notifications', to='terminusgps_notifier.wialonresource')),
            ],
            options={
                'verbose_name': 'wialon notification',
                'verbose_name_plural': 'wialon notifications',
            },
        ),
    ]



# Generated by Django 6.0.3 on 2026-03-18 16:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('terminusgps_notifier', '0003_alter_terminusgpsnotifiercustomer_tax_rate'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='terminusgpsnotifiercustomer',
            name='token',
        ),
        migrations.DeleteModel(
            name='WialonToken',
        ),
    ]
